summaryrefslogtreecommitdiffstats
path: root/macosx/Controller.h
diff options
context:
space:
mode:
authordynaflash <[email protected]>2007-06-29 17:00:01 +0000
committerdynaflash <[email protected]>2007-06-29 17:00:01 +0000
commit51a8906f6c81e91c65df6b4732359ee32fbbe74b (patch)
tree59a1e4301d181c293c486c827d7737789dce78fd /macosx/Controller.h
parent335b7a3c9938e14be5f0b21f3aca5d8500ad4310 (diff)
MacGui: Add description field and tooltips for Presets
- Add description NSTextField to the Add New Preset Panel - Added descriptions for the Built-In Presets (be sure to use "Update Built-In Presets" in the Presets menu to get descriptions) - Added Tooltips to the presets drawer which shows the description of the preset. git-svn-id: svn://svn.handbrake.fr/HandBrake/trunk@643 b64f7644-9d1e-0410-96f1-a4d463321fa5
Diffstat (limited to 'macosx/Controller.h')
-rw-r--r--macosx/Controller.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/macosx/Controller.h b/macosx/Controller.h
index 35b67ec3b..695fa98f6 100644
--- a/macosx/Controller.h
+++ b/macosx/Controller.h
@@ -175,10 +175,11 @@
IBOutlet NSPopUpButton * fX264optAlphaDeblockPopUp;
IBOutlet NSPopUpButton * fX264optBetaDeblockPopUp;
/* User Preset variables here fPresetNewPicSettingsApply*/
IBOutlet NSDrawer * fPresetDrawer;
IBOutlet NSTextField * fPresetNewName;
+ IBOutlet NSTextField * fPresetNewDesc;
IBOutlet NSPopUpButton * fPresetNewPicSettingsPopUp;
IBOutlet NSTextField * fPresetSelectedDisplay;
@@ -175,10 +175,11 @@
IBOutlet NSPopUpButton * fX264optAlphaDeblockPopUp;
IBOutlet NSPopUpButton * fX264optBetaDeblockPopUp;
- /* User Preset variables here fPresetNewPicSettingsApply*/
+ /* User Preset variables here fPresetNewDesc*/
IBOutlet NSDrawer * fPresetDrawer;
IBOutlet NSTextField * fPresetNewName;